@@ -31,17 +31,7 @@ class SetupCog(commands.Cog):
 
         try:
             await context.message.delete()
-            context.bot.tree.copy_global_to(guild=context.guild)
-            synced = await context.bot.tree.sync(guild=context.guild)
-            await context.send(f"Synced {len(synced)} commands from {platform.node()}.")
-            role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
-            bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
-            if platform.node().lower() == "secureerase":
-                print("Switching to Prod")
-                await bot_member.remove_roles(role)
-            else:
-                print("Switching to Dev")
-                await bot_member.add_roles(role)
+            await self.check_server()
         except discord.errors.NotFound:
             print("Not able to delete message")
             return
@@ -53,7 +43,7 @@ class SetupCog(commands.Cog):
             app_commands.Choice(name="All", value="all"),
         ]
     )
-    async def clear_command(self, context: discord.Interaction, scope: str):
+    async def clear_command(self, context: discord.Interaction, scope: str) -> None:
         """Clear all or bot messages in bot-config"""
         if context.channel.id != BOT_CHANNEL:
             await context.channel.send("Cannot use in this channel")
@@ -78,9 +68,13 @@ class SetupCog(commands.Cog):
     @commands.Cog.listener("on_ready")
     async def set_dev_rol(self):
         """Add dev role to activate bot if run from dev machine"""
+        await self.check_server()
+
+    async def check_server(self):
+        """Set bot role and sync commands"""
         self.client.tree.copy_global_to(guild=self.client.guilds[0])
         synced = await self.client.tree.sync(guild=self.client.guilds[0])
-        print(f"Synced {len(synced)} commands from {platform.node()}.")
+        await self.client.get_channel(BOT_CHANNEL).send(f"Synced {len(synced)} commands from {platform.node()}.")
         role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
         bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
         if platform.node().lower() == "secureerase":
